=======
History
=======

2.0.2 (2020-02-08)
------------------

* Fix source distribution, move to setuptools_scm

2.0.1 (2020-02-04)
------------------

* Add the concept of an exported/unexported glyph
* Revert "Ignore unexported glyphs"
* Ignore missing date
* Ignore unexported glyphs
* Fix VFJ test

2.0.0 (2020-01-25)
------------------

* Rewrite to load in font data directly instead of proxying. New interface.
* Fix anchors, color loading
* Add variable font abstraction layer

